Shows the estimate, the method that was chosen and why, the inference payload, and (when the "auto" mode ran) the latent-normality test.
Usage
# S3 method for class 'smartcor'
print(x, ...)Shows the estimate, the method that was chosen and why, the inference payload, and (when the "auto" mode ran) the latent-normality test.
# S3 method for class 'smartcor'
print(x, ...)