Prints the correlation matrix, the two-letter method codes for each cell, and a legend for the codes that appear.
Usage
# S3 method for class 'smartcormat'
print(x, digits = 2, show_methods = TRUE, ...)Prints the correlation matrix, the two-letter method codes for each cell, and a legend for the codes that appear.
# S3 method for class 'smartcormat'
print(x, digits = 2, show_methods = TRUE, ...)