Skip to contents

Lays a compare_methods() result out as a tibble with one row per candidate method, in the manner of the broom package.

Usage

# S3 method for class 'smartcor_comparison'
tidy(x, ...)

Arguments

x

A smartcor_comparison object.

...

Ignored.

Value

A tibble::tibble() with one row per method.