Lays a compare_methods() result out as a tibble with one row per
candidate method, in the manner of the broom package.
Usage
# S3 method for class 'smartcor_comparison'
tidy(x, ...)Value
A tibble::tibble() with one row per method.
Lays a compare_methods() result out as a tibble with one row per
candidate method, in the manner of the broom package.
# S3 method for class 'smartcor_comparison'
tidy(x, ...)A tibble::tibble() with one row per method.